@@ -19,16 +19,15 @@
 #ifndef CABOUT_H
 #define CABOUT_H
 
-#include "ui_IAbout.h"
 #include <QDialog>
 
-class CAbout : public QDialog, private Ui::IAbout
-{
-    Q_DECLARE_TR_FUNCTIONS(CAbout)
-public:
-    CAbout(QWidget* parent);
-    virtual ~CAbout();
+#include "ui_IAbout.h"
+
+class CAbout : public QDialog, private Ui::IAbout {
+  Q_DECLARE_TR_FUNCTIONS(CAbout)
+ public:
+  CAbout(QWidget* parent);
+  virtual ~CAbout();
 };
 
-#endif //CABOUT_H
-
+#endif  // CABOUT_H
