@@ -315,11 +315,7 @@ void CCanvas::buildHelpText() {
 
   const QString& msgDEMLinks =
       tr("<h2>&nbsp;</h2>"
-         "<p>Impatient Users:<p>"
-         "<ul>"
-         "<li><a href='GetDems'>I want some online DEMs.</a></li>"
-         "</ul>"
-         "<p>Patient Users:<p>"
+
          "<ul>"
          "<li><a href='https://github.com/Maproom/qmapshack/wiki/DocMapDemSources'>Sources for DEM</a></li>"
          "</ul>");
@@ -339,10 +335,7 @@ void CCanvas::buildHelpText() {
          "reference one "
          "or several other files. Again, you can use QMapShack's built-in VRT Builder (<a href='VrtBuilder'>Tool->VRT "
          "Builder</a>) "
-         "to create such a file.</p>"
-         "<p>To start with some online DEMs you can click on the link for <a href='GetDems'>impatient users</a>. But "
-         "keep in mind "
-         "that using online DEMs slows down QMapShack significantly.</p>");
+         "to create such a file.</p>");
 
   addHtmlRow(msg, msgDEMLinks, msgDem, "", "");
 
@@ -815,7 +808,7 @@ void CCanvas::slotToolTip() {
     }
   }
   QPoint p = mapToGlobal(posToolTip + QPoint(32, 0));
-  QToolTip::showText(p, str);
+  QToolTip::showText(p, str, this);
 }
 
 void CCanvas::slotCheckTrackOnFocus() {
