@@ -28,6 +28,7 @@
 #include "dem/IDem.h"
 #include "gis/IGisLine.h"
 #include "helpers/CSettings.h"
+#include "misc.h"
 #include "units/IUnit.h"
 
 QList<CDemDraw*> CDemDraw::dems;
@@ -81,7 +82,7 @@ void CDemDraw::setupDemPath(const QString& path) {
 void CDemDraw::setupDemPath(const QStringList& paths) {
   demPaths = paths;
 
-  for (CDemDraw* dem : qAsConst(dems)) {
+  for (CDemDraw* dem : std::as_const(dems)) {
     QStringList keys;
     dem->saveActiveMapsList(keys);
     dem->buildMapList();
@@ -124,7 +125,7 @@ void CDemDraw::buildMapList() {
   QMutexLocker lock(&CDemItem::mutexActiveDems);
   demList->clear();
 
-  for (const QString& path : qAsConst(demPaths)) {
+  for (const QString& path : std::as_const(demPaths)) {
     QDir dir(path);
     // find available maps
     const QStringList& filenames = dir.entryList(supportedFormats, QDir::Files | QDir::Readable, QDir::Name);
@@ -139,7 +140,7 @@ void CDemDraw::buildMapList() {
 
       // calculate MD5 hash from the file's first 1024 bytes
       QFile f(dir.absoluteFilePath(filename));
-      f.open(QIODevice::ReadOnly);
+      openFileCheckSuccess(QIODevice::ReadOnly, f);
       md5.reset();
       md5.addData(f.read(1024));
       item->key = md5.result().toHex();
