@@ -19,47 +19,54 @@
 #ifndef CDEMVRT_H
 #define CDEMVRT_H
 
-#include "dem/IDem.h"
-
 #include <QMutex>
+#include <QThreadPool>
+
+#include "dem/IDem.h"
 
 class CDemDraw;
 class GDALDataset;
 
-class CDemVRT : public IDem
-{
-    Q_OBJECT
-public:
-    CDemVRT(const QString& filename, CDemDraw* parent);
-    virtual ~CDemVRT();
+class CDemVRT : public IDem {
+  Q_OBJECT
+ public:
+  CDemVRT(const QString& filename, CDemDraw* parent);
+  virtual ~CDemVRT();
 
-    void draw(IDrawContext::buffer_t& buf) override;
+  void draw(IDrawContext::buffer_t& buf) override;
 
-    qreal getElevationAt(const QPointF& pos, bool checkScale) override;
-    qreal getSlopeAt(const QPointF& pos, bool checkScale) override;
+  qreal getElevationAt(const QPointF& pos, bool checkScale) override;
+  qreal getSlopeAt(const QPointF& pos, bool checkScale) override;
 
-private:
-    QMutex mutex;
+ private slots:
+  void slotNeedsRedraw();
 
-    QString filename;
-    /// instance of GDAL dataset
-    GDALDataset* dataset;
+ private:
+  using IDem::drawTile;
+  void drawElevationShadeScale(QPainter& p) const;
+  void drawTile(const qint32 x, const qint32 y, const qint32 w, const qint32 h,
+                const qreal o1, const qreal o2, QPainter& p) const;
 
+  mutable QMutex mutex;
 
-    QPointF ref1;
-    QPointF ref2;
-    QPointF ref3;
-    QPointF ref4;
+  QString filename;
+  /// instance of GDAL dataset
+  GDALDataset* dataset;
 
-    QTransform trFwd;
-    QTransform trInv;
+  QPointF ref1;
+  QPointF ref2;
+  QPointF ref3;
+  QPointF ref4;
 
-    bool hasOverviews = false;
+  QTransform trFwd;
+  QTransform trInv;
 
-    QRectF boundingBox;
+  bool hasOverviews = false;
+  bool outOfScale = false;
 
-    bool outOfScale = false;
+  QRectF boundingBox;
+
+  QThreadPool threadPool;
 };
 
-#endif //CDEMVRT_H
-
+#endif  // CDEMVRT_H
