@@ -227,25 +227,12 @@ CGisItemTrk::CGisItemTrk(CTrackData& trkdata, IGisProject* project)
   checkForInvalidPoints();
 }
 
-CGisItemTrk::CGisItemTrk(CFitStream& stream, IGisProject* project)
-    : IGisItem(project, eTypeTrk, project->childCount()) {
-  // --- start read and process data ----
-  setColor(penForeground.color());
-  readTrkFromFit(stream);
-  // --- stop read and process data ----
-
-  setupHistory();
-  deriveSecondaryData();
-  updateDecoration(eMarkNone, eMarkNone);
-
-  checkForInvalidPoints();
-}
 
 CGisItemTrk::~CGisItemTrk() {
   // reset user focus if focused on this track
   if (key == keyUserFocus) {
-    keyUserFocus.clear();
-  }
+  keyUserFocus.clear();
+}
 
   /*
       Delete all registered INotifyTrk as they can't exist without the item.
@@ -354,7 +341,7 @@ QString CGisItemTrk::getInfoLimits() const {
   QStringList keys = extrema.keys();
   std::sort(keys.begin(), keys.end(), sortByString);
 
-  for (const QString& key : qAsConst(keys)) {
+  for (const QString& key : std::as_const(keys)) {
     if (key == CKnownExtension::internalSpeedTime)  // Output of "Speed*" will already be covered by internalSpeedDist
     {                                               // No need to show it twice
       continue;
@@ -487,7 +474,7 @@ QString CGisItemTrk::getInfo(quint32 feature) const {
     }
 
     QString desc = removeHtml(trk.desc).simplified();
-    if (desc.count()) {
+    if (desc.length()) {
       if (!str.isEmpty()) {
         str += "<br/>\n";
       }
@@ -495,7 +482,7 @@ QString CGisItemTrk::getInfo(quint32 feature) const {
     }
 
     QString cmt = removeHtml(trk.cmt).simplified();
-    if ((cmt != desc) && cmt.count()) {
+    if ((cmt != desc) && cmt.length()) {
       if (!str.isEmpty()) {
         str += "<br/>\n";
       }
@@ -537,14 +524,14 @@ QString CGisItemTrk::getInfoRange() const {
   }
 
   bool timeIsValid = pt1->time.isValid() && pt2->time.isValid();
-  qreal deltaTime = pt2->time.toTime_t() - pt1->time.toTime_t();
+  qreal deltaTime = pt2->time.toSecsSinceEpoch() - pt1->time.toSecsSinceEpoch();
 
   const qreal distance = pt2->distance - pt1->distance;
 
   IUnit::self().meter2distance(distance, val, unit);
   str += QString("%3 %1%2 ").arg(val, unit).arg(QChar(0x21A6));
   if (timeIsValid) {
-    quint32 t = pt2->time.toTime_t() - pt1->time.toTime_t();
+    quint32 t = pt2->time.toSecsSinceEpoch() - pt1->time.toSecsSinceEpoch();
     quint32 hh = t / 3600;
     quint32 mm = (t % 3600) / 60;
     quint32 ss = t % 60;
@@ -624,7 +611,7 @@ QString CGisItemTrk::getInfoTrkPt(const CTrackData::trkpt_t& pt) const {
     keys = keys.mid(0, 10);
   }
 
-  for (const QString& key : qAsConst(keys)) {
+  for (const QString& key : std::as_const(keys)) {
     const CKnownExtension& ext = CKnownExtension::get(key);
     if (ext.known) {
       str +=
@@ -652,12 +639,14 @@ QString CGisItemTrk::getInfoProgress(const CTrackData::trkpt_t& pt) const {
 
   if (pt.ascent != NOFLOAT) {
     IUnit::self().meter2elevation(pt.ascent, val, unit);
-    asc = tr("Ascent: %1%2 (%3%)").arg(val, unit).arg(pt.ascent * 100 / totalAscent, 2, 'f', 0);
+    qreal slope = totalAscent ? (pt.ascent * 100 / totalAscent) : 0;
+    asc = tr("Ascent: %1%2 (%3%)").arg(val, unit).arg(slope, 2, 'f', 0);
   }
 
   if (pt.descent != NOFLOAT) {
     IUnit::self().meter2elevation(pt.descent, val, unit);
-    dsc = tr(", Descent: %1%2 (%3%)").arg(val, unit).arg(pt.descent * 100 / totalDescent, 2, 'f', 0);
+    qreal  slope = totalDescent ? (pt.descent * 100 / totalDescent) : 0;
+    dsc = tr("Descent: %1%2 (%3%)").arg(val, unit).arg(slope, 2, 'f', 0);
   }
 
   if (pt.distance != NOFLOAT) {
@@ -686,7 +675,7 @@ QString CGisItemTrk::getInfoRange(const CTrackData::trkpt_t& trkpt1, const CTrac
   }
 
   if (pt1.time.isValid() && pt2.time.isValid()) {
-    dt = pt2.time.toTime_t() - pt1.time.toTime_t();
+    dt = pt2.time.toSecsSinceEpoch() - pt1.time.toSecsSinceEpoch();
   }
 
   QString asc = tr("Ascent: -");
@@ -991,10 +980,10 @@ void CGisItemTrk::deriveSecondaryData() {
         continue;
       }
 
+      d1 = trkpt2.distance;
+      e1 = trkpt2.ele;
+      t1 = trkpt2.time.toMSecsSinceEpoch() / 1000.0;
       if (trkpt.distance - trkpt2.distance >= 25) {
-        d1 = trkpt2.distance;
-        e1 = trkpt2.ele;
-        t1 = trkpt2.time.toMSecsSinceEpoch() / 1000.0;
         break;
       }
     }
@@ -1008,10 +997,10 @@ void CGisItemTrk::deriveSecondaryData() {
         continue;
       }
 
+      d2 = trkpt2.distance;
+      e2 = trkpt2.ele;
+      t2 = trkpt2.time.toMSecsSinceEpoch() / 1000.0;
       if (trkpt2.distance - trkpt.distance >= 25) {
-        d2 = trkpt2.distance;
-        e2 = trkpt2.ele;
-        t2 = trkpt2.time.toMSecsSinceEpoch() / 1000.0;
         break;
       }
     }
@@ -1149,11 +1138,11 @@ void CGisItemTrk::findWaypointsCloseBy(CProgressDialog& progress, quint32& curre
 
   bool doDeriveData = false;
   numberOfAttachedWpt = 0;
-  for (const trkwpt_t& trkwpt : qAsConst(trkwpts)) {
+  for (const trkwpt_t& trkwpt : std::as_const(trkwpts)) {
     qreal minD = WPT_FOCUS_DIST_IN;
     qint32 index = NOIDX;
 
-    for (const pointDP& pt : qAsConst(line)) {
+    for (const pointDP& pt : std::as_const(line)) {
       ++current;
       qreal d = (trkwpt.x - pt.x) * (trkwpt.x - pt.x) + (trkwpt.y - pt.y) * (trkwpt.y - pt.y);
 
@@ -1302,7 +1291,7 @@ bool CGisItemTrk::cut() {
                  isInRange(removeEnd, seg.pts.first().idxTotal, seg.pts.last().idxTotal)) {
         QVector<CTrackData::trkpt_t> pts;
 
-        for (const CTrackData::trkpt_t& pt : qAsConst(seg.pts)) {
+        for (const CTrackData::trkpt_t& pt : std::as_const(seg.pts)) {
           if (!(removeStart <= pt.idxTotal && pt.idxTotal <= removeEnd)) {
             pts << pt;
           }
@@ -1373,7 +1362,7 @@ void CGisItemTrk::reverse() {
   trk1->key.clear();
   trk1->history.events.clear();
 
-  for (const CTrackData::trkseg_t& seg : qAsConst(trk.segs)) {
+  for (const CTrackData::trkseg_t& seg : std::as_const(trk.segs)) {
     CTrackData::trkseg_t seg1;
     for (const CTrackData::trkpt_t& pt : seg.pts) {
       CTrackData::trkpt_t pt1 = pt;
@@ -1500,7 +1489,7 @@ void CGisItemTrk::deleteSelectedPoints() {
 
   for (CTrackData::trkseg_t& seg : trk.segs) {
     QVector<CTrackData::trkpt_t> pts;
-    for (const CTrackData::trkpt_t& pt : qAsConst(seg.pts)) {
+    for (const CTrackData::trkpt_t& pt : std::as_const(seg.pts)) {
       if (idx1 < pt.idxTotal && pt.idxTotal < idx2) {
         continue;
       }
@@ -1623,12 +1612,12 @@ void CGisItemTrk::drawItem(QPainter& p, const QPolygonF& viewport, QList<QRectF>
 
     p.setPen(QPen(Qt::lightGray, penWidthBg, Qt::SolidLine, Qt::RoundCap, Qt::RoundJoin));
 
-    for (const QPolygonF& l : qAsConst(lines)) {
+    for (const QPolygonF& l : std::as_const(lines)) {
       p.drawPolyline(l);
     }
 
     QPixmap bullet("://icons/8x8/bullet_dark_gray.png");
-    for (const QPolygonF& l : qAsConst(lines)) {
+    for (const QPolygonF& l : std::as_const(lines)) {
       for (const QPointF& pt : l) {
         p.drawPixmap(pt.x() - 3, pt.y() - 3, bullet);
       }
@@ -1643,14 +1632,14 @@ void CGisItemTrk::drawItem(QPainter& p, const QPolygonF& viewport, QList<QRectF>
   const CMainWindow& w = CMainWindow::self();
   if (key == keyUserFocus && w.isShowTrackHighlight()) {
     p.setPen(QPen(Qt::red, penWidthHi, Qt::SolidLine, Qt::RoundCap, Qt::RoundJoin));
-    for (const QPolygonF& l : qAsConst(lines)) {
+    for (const QPolygonF& l : std::as_const(lines)) {
       p.drawPolyline(l);
     }
   }
 
   p.setBrush(color);
   p.setPen(penBackground);
-  for (const QPolygonF& l : qAsConst(lines)) {
+  for (const QPolygonF& l : std::as_const(lines)) {
     p.drawPolyline(l);
     const QRectF& bounding = l.boundingRect();
     auto area = bounding.width() * bounding.height();
@@ -1663,7 +1652,7 @@ void CGisItemTrk::drawItem(QPainter& p, const QPolygonF& viewport, QList<QRectF>
     // use the track's ordinary color
     penForeground.setColor(color);
     p.setPen(penForeground);
-    for (const QPolygonF& l : qAsConst(lines)) {
+    for (const QPolygonF& l : std::as_const(lines)) {
       p.drawPolyline(l);
     }
   } else if (getColorizeSource() == "activity") {
@@ -1673,7 +1662,7 @@ void CGisItemTrk::drawItem(QPainter& p, const QPolygonF& viewport, QList<QRectF>
   }
 
   if (isNogo()) {
-    for (const QPolygonF& l : qAsConst(lines)) {
+    for (const QPolygonF& l : std::as_const(lines)) {
       CDraw::nogos(l, extViewport, p, 80);
     }
   }
@@ -2093,7 +2082,7 @@ void CGisItemTrk::drawHighlight(QPainter& p) {
 
   p.setPen(QPen(QColor(255, 0, 0, 100), penWidthHi, Qt::SolidLine, Qt::RoundCap, Qt::RoundJoin));
 
-  for (const QPolygonF& line : qAsConst(lines)) {
+  for (const QPolygonF& line : std::as_const(lines)) {
     p.drawPolyline(line);
   }
 }
@@ -2309,7 +2298,7 @@ bool CGisItemTrk::setMouseFocusByTime(quint32 time, focusmode_e fmode, const QSt
         continue;
       }
 
-      qreal d = qAbs(qreal(pt.time.toTime_t()) - qreal(time));
+      qreal d = qAbs(qreal(pt.time.toSecsSinceEpoch()) - qreal(time));
       if (d <= delta) {
         newPointOfFocus = &pt;
         delta = d;
@@ -2588,7 +2577,7 @@ void CGisItemTrk::updateVisuals(quint32 visuals, const QString& who) {
     dlgDetails->updateData();
   }
 
-  for (INotifyTrk* visual : qAsConst(registeredVisuals)) {
+  for (INotifyTrk* visual : std::as_const(registeredVisuals)) {
     if (visuals & visual->mask) {
       visual->updateData();
     }
@@ -2606,7 +2595,7 @@ void CGisItemTrk::setMouseFocusVisuals(const CTrackData::trkpt_t* pt) {
     dlgDetails->setMouseFocus(pt);
   }
 
-  for (INotifyTrk* visual : qAsConst(registeredVisuals)) {
+  for (INotifyTrk* visual : std::as_const(registeredVisuals)) {
     visual->setMouseFocus(pt);
   }
 }
@@ -2616,7 +2605,7 @@ void CGisItemTrk::setMouseRangeFocusVisuals(const CTrackData::trkpt_t* pt1, cons
     dlgDetails->setMouseRangeFocus(pt1, pt2);
   }
 
-  for (INotifyTrk* visual : qAsConst(registeredVisuals)) {
+  for (INotifyTrk* visual : std::as_const(registeredVisuals)) {
     visual->setMouseRangeFocus(pt1, pt2);
   }
 }
@@ -2626,7 +2615,7 @@ void CGisItemTrk::setMouseClickFocusVisuals(const CTrackData::trkpt_t* pt) {
     dlgDetails->setMouseClickFocus(pt);
   }
 
-  for (INotifyTrk* visual : qAsConst(registeredVisuals)) {
+  for (INotifyTrk* visual : std::as_const(registeredVisuals)) {
     visual->setMouseClickFocus(pt);
   }
 }
@@ -2658,22 +2647,15 @@ void CGisItemTrk::setupInterpolation(bool on, qint32 q) {
     y[trkpt.idxVisible] = trkpt.ele;
   }
 
-  /// @todo find a better way to scale the algorithm
-  interp.m = interp.Q * 50;
-  if (N < 400) {
-    interp.m = N / (16 / interp.Q);
-  }
-
-  interp.m &= 0xFFFFFFFE;
+  interp.m = interp.Q * N / 10;
 
   try {
-    alglib::spline1dfitcubic(x, y, interp.m, interp.info, interp.p, interp.rep);
+    alglib::spline1dfit(x, y, interp.m, 0.00001, interp.p, interp.rep);
+    interp.valid = true;
   } catch (const alglib::ap_error& e) {
     qWarning() << "Error from alglib: " << e.msg.c_str();
   }
 
-  interp.valid = interp.info > 0;
-
   updateVisuals(eVisualPlot, "setupInterpolation()");
 }
 
