@@ -159,9 +159,10 @@ CGisItemWpt::CGisItemWpt(const CTwoNavProject::wpt_t& tnvWpt, IGisProject* proje
   updateDecoration(eMarkNone, eMarkNone);
 }
 
-CGisItemWpt::CGisItemWpt(CFitStream& stream, IGisProject* project)
+
+CGisItemWpt::CGisItemWpt(const wpt_t& data, IGisProject* project)
     : IGisItem(project, eTypeWpt, NOIDX), proximity(NOFLOAT), posScreen(NOPOINTF) {
-  readWptFromFit(stream);
+  wpt = data;
   detBoundingRect();
 
   CGisItemWpt::genKey();
@@ -209,7 +210,7 @@ QString CGisItemWpt::getLastName(const QString& name) {
     if (idx == 0) {
       lastName = QString::number(lastName.toInt() + 1);
     } else if (idx < s) {
-      lastName = lastName.left(idx) + QString::number(lastName.midRef(idx).toInt() + 1);
+      lastName = lastName.left(idx) + QString::number(lastName.mid(idx).toInt() + 1);
     }
   }
 
@@ -328,12 +329,12 @@ QString CGisItemWpt::getInfo(quint32 feature) const {
       }
     }
   } else {
-    if (desc.count()) {
+    if (desc.length()) {
       if (str.size() > initialSize) {
         str += "<br/>\n";
       }
 
-      if ((feature & eFeatureShowFullText) || (desc.count() < 300)) {
+      if ((feature & eFeatureShowFullText) || (desc.length() < 300)) {
         str += desc;
       } else {
         str += desc.left(297) + "...";
@@ -342,12 +343,12 @@ QString CGisItemWpt::getInfo(quint32 feature) const {
   }
 
   QString cmt = removeHtml(wpt.cmt).simplified();
-  if ((cmt != desc) && cmt.count()) {
+  if ((cmt != desc) && cmt.length()) {
     if (str.size() > initialSize) {
       str += "<br/>\n";
     }
 
-    if ((feature & eFeatureShowFullText) || (cmt.count() < 300)) {
+    if ((feature & eFeatureShowFullText) || (cmt.length() < 300)) {
       str += cmt;
     } else {
       str += cmt.left(297) + "...";
@@ -564,9 +565,14 @@ void CGisItemWpt::drawItem(QPainter& p, const QPolygonF& viewport, QList<QRectF>
 
   drawBubble(p);
 
-  p.drawPixmap(posScreen - focus, icon);
+  // for accuracy reasons, it is not sufficient to upscale 22 pixel icon
+  // get scaled waypoint icon here, as size might have changed in between
+  QPointF focusScaled;
+  const QPixmap& iconScaled = CWptIconManager::self().getWptIconScaledByName(getIconName(), focusScaled);
 
-  blockedAreas << QRectF(posScreen - focus, icon.size());
+  p.drawPixmap(posScreen - focusScaled, iconScaled);
+
+  blockedAreas << QRectF(posScreen - focusScaled, iconScaled.size());
 }
 
 void CGisItemWpt::drawItem(QPainter& p, const QRectF& /*viewport*/, CGisDraw* gis) {
@@ -607,19 +613,24 @@ void CGisItemWpt::drawLabel(QPainter& p, const QPolygonF& /*viewport*/, QList<QR
     return;
   }
 
-  QPointF pt = posScreen - focus;
+  // for accuracy reasons, it is not sufficient to upscale 22 pixel icon
+  // get scaled waypoint icon here, as size might have changed in between
+  QPointF focusScaled;
+  const QPixmap& iconScaled = CWptIconManager::self().getWptIconScaledByName(getIconName(), focusScaled);
+
+  QPointF pt = posScreen - focusScaled;
 
   QRectF rect = fm.boundingRect(wpt.name);
   rect.adjust(-2, -2, 2, 2);
 
   // place label on top
-  rect.moveCenter(pt + QPointF(icon.width() / 2, -fm.height()));
+  rect.moveCenter(pt + QPointF(iconScaled.width() / 2, -fm.height()));
   if (CDraw::doesOverlap(blockedAreas, rect)) {
     // place label on bottom
-    rect.moveCenter(pt + QPointF(icon.width() / 2, +fm.height() + icon.height()));
+    rect.moveCenter(pt + QPointF(iconScaled.width() / 2, +fm.height() + icon.height()));
     if (CDraw::doesOverlap(blockedAreas, rect)) {
       // place label on right
-      rect.moveCenter(pt + QPointF(icon.width() + rect.width() / 2, +fm.height()));
+      rect.moveCenter(pt + QPointF(iconScaled.width() + rect.width() / 2, +fm.height()));
       if (CDraw::doesOverlap(blockedAreas, rect)) {
         // place label on left
         rect.moveCenter(pt + QPointF(-rect.width() / 2, +fm.height()));
@@ -643,7 +654,10 @@ void CGisItemWpt::drawHighlight(QPainter& p) {
   if (closeToRadius) {
     drawCircle(p, posScreen, radius, false, true);
   } else {
-    p.drawImage(posScreen - QPointF(31, 31), QImage("://cursors/wptHighlightRed.png"));
+    const QImage& iconHighlight = CWptIconManager::self().iconHighlight();
+    QRectF r = iconHighlight.rect();
+    r.moveCenter(posScreen);
+    p.drawImage(r, iconHighlight);
   }
 }
 
@@ -1180,7 +1194,7 @@ QMap<searchProperty_e, CGisItemWpt::fSearch> CGisItemWpt::initKeywordLambdaMap()
   });
   map.insert(eSearchPropertyGeocacheLoggedBy, [](CGisItemWpt* item) {
     searchValue_t searchValue;
-    for (const geocachelog_t& log : qAsConst(item->geocache.logs)) {
+    for (const geocachelog_t& log : std::as_const(item->geocache.logs)) {
       searchValue.str1 += log.finder + ", ";
     }
     return searchValue;
