@@ -58,7 +58,7 @@ void IScrOpt::moveTo(const QPoint& anchor) {
 
 void IScrOpt::mouseMove(const QPoint& pos) { mousePos = pos; }
 
-void IScrOpt::enterEvent(QEvent* e) {
+void IScrOpt::enterEvent(QEnterEvent* e) {
   QWidget::enterEvent(e);
   CCanvas::restoreOverrideCursor("IScrOpt::enterEvent");
 }
@@ -70,6 +70,11 @@ void IScrOpt::leaveEvent(QEvent* e) {
   }
 }
 
+void IScrOpt::paintEvent(QPaintEvent* e) {
+  QPainter p(this);
+  draw(p);
+}
+
 void IScrOpt::slotLinkActivated(const QString& link) {
   if (link.startsWith("http")) {
     QDesktopServices::openUrl(QUrl(link));
